PlatformUtils extension
- on
Static Properties
- isAndroid → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isDesktop → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isFuchsia → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isIOS → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isLinux → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isMacOS → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isMobile → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isOS → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetAndroid → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetDesktop → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetFuchsia → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetIOS → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetLinux → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetMacOS → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetMobile → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isTargetWindows → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isWeb → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - isWindows → bool
-
Available on PlatformType, provided by the PlatformUtils extension
no setter - targetType → PlatformType
-
Available on PlatformType, provided by the PlatformUtils extension
The targetType is the same as type in most of the cases, unless when type is web, in that case targetType will be the platform the browser is running on.no setter - type → PlatformType
-
Available on PlatformType, provided by the PlatformUtils extension
The specific platform the app is running on, or web if running on webno setter